@@ -817,131 +817,6 @@ static PyObject* is_satisfiable(Solver *self)
     }
 }
 
-PyDoc_STRVAR(msolve_selected_doc,
-"msolve_selected(max_nr_of_solutions, var_selected, raw=True)\n\
-Find multiple solutions to your problem, the solver is ran in a loop and each\n\
-previous solution found will be banned.\n\
-\n\
-.. warning:: The loop will run as long as there are solutions.\n\
-    a maximum of loops must be set with 'max_nr_of_solutions' parameter\n\
-\n\
-.. note:: As it is highly suggested in the documentation of cryptominisat,\n\
-    the new clause (banned solutions) contains the variables that are \n\
-    \"important\" or \"main\" to your problem (i.e. \"var_selected\" argument).\n\
-    Variables that were only used to translate the original problem into CNF \n\
-    should not be added.\n\
-    This way, you will not get spurious solutions that don't differ in \n\
-    the main, important variables.\n\
-\n\
-:param max_nr_of_solutions: Maximum number of solutions before stop the search\n\
-:type max_nr_of_solutions: <int>\n\
-:param var_selected: Variables for which the solver must find different solutions\n\
-:type var_selected: <list>\n\
-:param raw: (Optional) Format of literals for each solution returned. \n\
-    If set to True, lists of literals will be returned;\n\
-    .. example:: [(1, -2, -3, -4, -5, -6, -7, -8, -9, 10,),]\n\
-    if set to False, tuples of booleans will be returned,\n\
-    with None at the first position.\n\
-    .. example:: [(None, True, False, True,),]\n\
-:type raw: <boolean>\n\
-:return: List of solutions (list of tuples of literals)\n\
-:rtype: <list <tuple>>"
-);
-
-static PyObject* msolve_selected(Solver *self, PyObject *args, PyObject *kwds)
-{
-    int max_nr_of_solutions;
-    int raw_solutions_activated = true;
-    PyObject *var_selected;
-
-    static char const* kwlist[] = {"max_nr_of_solutions", "var_selected", "raw", NULL};
-
-    // Use 'p' wildcard for the boolean on version 3.3+ of Python
-    if (!PyArg_ParseTupleAndKeywords(args, kwds, "iO|p", const_cast<char**>(kwlist),
-                                     &max_nr_of_solutions,
-                                     &var_selected,
-                                     &raw_solutions_activated)) {
-        return NULL;
-    }
-
-    std::vector<Lit> var_lits;
-    if (!parse_clause(self, var_selected, var_lits)) {
-        return 0;
-    }
-
-    PyObject *solutions = PyList_New(0);
-    if (solutions == NULL) {
-        PyErr_SetString(PyExc_SystemError, "failed to create a list");
-        return NULL;
-    }
-
-    int current_nr_of_solutions = 0;
-    lbool res = l_True;
-    PyObject* solution = NULL;
-    while((current_nr_of_solutions < max_nr_of_solutions) && (res == l_True)) {
-
-        Py_BEGIN_ALLOW_THREADS      /* release GIL */
-        res = self->cmsat->solve();
-        Py_END_ALLOW_THREADS
-
-        current_nr_of_solutions++;
-        if(res == l_True) {
-
-            // Memorize the solution
-            if (!raw_solutions_activated) {
-                // Solution in v5 format
-                solution = get_solution(self->cmsat);
-            } else {
-                // Solution in v2.9 format
-                solution = get_raw_solution(self->cmsat);
-            }
-
-            if (!solution) {
-                PyErr_SetString(PyExc_SystemError, "no solution");
-                Py_DECREF(solutions);
-                return NULL;
-            }
-            // Add solution
-            PyList_Append(solutions, solution);
-            Py_DECREF(solution);
-
-            // Prepare next statement
-            // Ban previous solution
-            if (current_nr_of_solutions < max_nr_of_solutions) {
-
-                std::vector<Lit> ban_solution;
-                const std::vector<lbool> model = self->cmsat->get_model();
-
-                // Iterate on var_selected (instead of iterate on all vars in solver)
-                for (unsigned long i = 0; i < var_lits.size(); i++) {
-                    if (var_lits[i].sign() == false) {
-                        assert(var_lits[i].var() <= (uint32_t)self->cmsat->nVars());
-                        ban_solution.push_back(
-                            Lit(var_lits[i].var(), (model[var_lits[i].var()] == l_True) ? true : false)
-                        );
-                    }
-                }
-
-                // Ban current solution for the next run
-                self->cmsat->add_clause(ban_solution);
-            }
-        } else if (res == l_False) {
-            // std::cout << "DEBUG :: Solver: No more solution" << std::endl;
-        } else if (res == l_Undef) {
-            Py_DECREF(solutions);
-            PyErr_SetString(PyExc_SystemError, "Nothing to do => sol undef");
-            return NULL;
-        } else {
-            // res can only be l_False, l_True, l_Undef
-            assert((res == l_False) || (res == l_True) || (res == l_Undef));
-            Py_DECREF(solutions);
-            return NULL;
-        }
-    }
-    // Return list of all solutions
-    return solutions;
-}
-
 PyDoc_STRVAR(get_conflict_doc,
 "get_conflict()\n\
 Returns the conflicts in the assumptions when the last call to solve(...)\n\
@@ -980,7 +855,6 @@ static PyMethodDef Solver_methods[] = {
     {"add_xor_clause",(PyCFunction) add_xor_clause,  METH_VARARGS | METH_KEYWORDS, "adds an XOR clause to the system"},
     {"nb_vars", (PyCFunction) nb_vars, METH_VARARGS | METH_KEYWORDS, nb_vars_doc},
     //{"nb_clauses", (PyCFunction) nb_clauses, METH_VARARGS | METH_KEYWORDS, "returns number of clauses"},
-    {"msolve_selected", (PyCFunction) msolve_selected, METH_VARARGS | METH_KEYWORDS, msolve_selected_doc},
     {"is_satisfiable", (PyCFunction) is_satisfiable, METH_VARARGS | METH_KEYWORDS, is_satisfiable_doc},
     {"get_conflict", (PyCFunction) get_conflict, METH_VARARGS | METH_KEYWORDS, get_conflict_doc},
 
@@ -1083,7 +957,11 @@ MODULE_INIT_FUNC(pycryptosat)
 
     // Add the version string so users know what version of CryptoMiniSat
     // they're using.
-    if (PyModule_AddStringConstant(m, "__version__", "${CMS_FULL_VERSION}") == -1) {
+    if (PyModule_AddStringConstant(m, "__version__", CMS_FULL_VERSION) == -1) {
+        Py_DECREF(m);
+        return NULL;
+    }
+    if (PyModule_AddStringConstant(m, "VERSION", CMS_FULL_VERSION) == -1) {
         Py_DECREF(m);
         return NULL;
     }
